@@ -6,13 +6,15 @@ use strict;
 
 require Exporter;
 *import = *import = \&Exporter::import;
+
 use vars qw( @EXPORT_OK %EXPORT_TAGS );
-@EXPORT_OK = qw( @Scalars @Arrays @Hashes @FileHandles @Symbols
-    @Functions @Barewords );
-%EXPORT_TAGS = ( ':all' => \@EXPORT_OK );
+@EXPORT_OK = qw( @Scalars @Arrays @Hashes @Filehandles @Symbols
+                 @Functions @Barewords @TieIOMethods @UNIVERSALMethods
+                 @ExporterSymbols );
+%EXPORT_TAGS = ( 'all' => \@EXPORT_OK );
 
 use vars '$VERSION';
-$VERSION = '1.08';
+$VERSION = '1.14';
 
 use vars '@Scalars';
 @Scalars = (
@@ -27,7 +29,7 @@ use vars '@Scalars';
         $. $INPUT_LINE_NUMBER $NR
         $/ $INPUT_RECORD_SEPARATOR $RS
         $| $OUTPUT_AUTO_FLUSH ), '$,', qw( $OUTPUT_FIELD_SEPARATOR $OFS
-        $OUTPUT_RECORD_SEPARATOR $ORS
+        $\ $OUTPUT_RECORD_SEPARATOR $ORS
         $" $LIST_SEPARATOR
         $; $SUBSCRIPT_SEPARATOR $SUBSEP
         ), '$#', qw( $OFMT
@@ -50,18 +52,23 @@ use vars '@Scalars';
         $]
         $^A $ACCUMULATOR
         $^C $COMPILING
+        $^CHILD_ERROR_NATIVE
         $^D $DEBUGGING
         $^E $EXTENDED_OS_ERROR
         $^ENCODING
         $^F $SYSTEM_FD_MAX
+        $^GLOBAL_PHASE
         $^H
         $^I $INPLACE_EDIT
         $^L $FORMAT_FORMFEED
+        $^LAST_FH
         $^M
-        $^N
+        $^MATCH
+        $^N $LAST_SUBMATCH_RESULT
         $^O $OSNAME
         $^OPEN
         $^P $PERLDB
+        $^PREMATCH $^POSTMATCH
         $^R $LAST_REGEXP_CODE_RESULT
         $^RE_DEBUG_FLAGS
         $^RE_TRIE_MAXBUF
@@ -69,10 +76,12 @@ use vars '@Scalars';
         $^T $BASETIME
         $^TAINT
         $^UNICODE
+        $^UTF8CACHE
         $^UTF8LOCALE
         $^V $PERL_VERSION
         $^W $WARNING $^WARNING_BITS
         $^WIDE_SYSTEM_CALLS
+        $^WIN32_SLOPPY_STAT
         $^X $EXECUTABLE_NAME
         $ARGV
         ),
@@ -83,14 +92,17 @@ use vars '@Arrays';
     @+ $LAST_MATCH_END
     @- @LAST_MATCH_START
     @ARGV
+    @F
     @INC
-    @_
+    @_ @ARG
 );
 
 use vars '@Hashes';
 @Hashes = qw(
     %OVERLOAD
-    %!
+    %+ %LAST_MATCH_END
+    %- %LAST_MATCH_START
+    %! %OS_ERROR %ERRNO
     %^H
     %INC
     %ENV
@@ -100,7 +112,9 @@ use vars '@Hashes';
 use vars '@Filehandles';
 @Filehandles = qw(
     *ARGV ARGV
+    *_ _
     ARGVOUT
+    DATA
     STDIN
     STDOUT
     STDERR
@@ -108,6 +122,7 @@ use vars '@Filehandles';
 
 use vars '@Functions';
 @Functions = qw(
+    __SUB__
     AUTOLOAD
     BEGIN
     DESTROY
@@ -151,9 +166,12 @@ use vars '@Functions';
     endservent
     eof
     eval
+    evalbytes
     exec
     exists
     exit
+    exp
+    fc
     fcntl
     fileno
     flock
@@ -193,6 +211,7 @@ use vars '@Functions';
     hex
     index
     int
+    import
     ioctl
     join
     keys
@@ -304,6 +323,7 @@ use vars '@Functions';
     umask
     undef
     unlink
+    unimport
     unpack
     unshift
     untie
@@ -348,8 +368,6 @@ use vars '@Barewords';
     else
     elsif
     eq
-    err
-    exp
     for
     foreach
     ge
@@ -381,6 +399,29 @@ use vars '@Barewords';
     y
 );
 
+use vars '@TieIOMethods';
+@TieIOMethods = qw(
+    BINMODE CLEAR CLEARERR CLONE CLONE_SKIP CLOSE DELETE EOF
+    ERROR EXISTS EXTEND FDOPEN FETCH FETCHSIZE FILENO FILL FIRSTKEY FLUSH
+    GETC NEXTKEY OPEN POP POPPED PRINT PRINTF PUSH PUSHED READ READLINE
+    SCALAR SEEK SETLINEBUF SHIFT SPLICE STORE STORESIZE SYSOPEN TELL
+    TIEARRAY TIEHANDLE TIEHASH TIESCALAR UNREAD UNSHIFT UNTIE UTF8 WRITE
+);
+
+use vars '@UNIVERSALMethods';
+@UNIVERSALMethods = qw(
+    can isa DOES VERSION
+);
+
+use vars '@ExporterSymbols';
+@ExporterSymbols = qw(
+    @EXPORT @EXPORT_OK @EXPORT_FAIL
+    @EXPORT_TAGS _push_tags _rebuild_cache as_heavy export export_fail
+    export_fail_in export_ok_tags export_tags export_to_level heavy_export
+    heavy_export_ok_tags heavy_export_tags heavy_export_to_level
+    heavy_require_version require_version
+);
+
 use vars '@Symbols';
 @Symbols = ( @Scalars, @Arrays, @Hashes, @Filehandles, @Functions );
 
@@ -391,27 +432,39 @@ BEGIN { $^W = 0 }
 
 __END__
 
+=encoding UTF-8
+
 =head1 NAME
 
 B::Keywords - Lists of reserved barewords and symbol names
 
 =head1 SYNOPSIS
 
-  use B::Keywords qw( @Symbols Barewords );
+  use B::Keywords qw( @Symbols @Barewords );
   print join "\n", @Symbols,
                    @Barewords;
 
 =head1 DESCRIPTION
 
-C<B::Keywords> supplies seven arrays of keywords: C<@Scalars>,
-C<@Arrays>, C<@Hashes>, C<@Filehandles>, C<@Symbols>, C<@Functions>,
-and C<@Barewords>. The C<@Symbols> array includes the contents of each
-of C<@Scalars>, C<@Arrays>, C<@Hashes>, and C<@Filehandles>.
+C<B::Keywords> supplies several arrays of exportable keywords:
+C<@Scalars>, C<@Arrays>, C<@Hashes>, C<@Filehandles>, C<@Symbols>,
+C<@Functions>, C<@Barewords>, C<@TieIOMethods>, C<@UNIVERSALMethods>
+and C<@ExporterSymbols>.
+
+The C<@Symbols> array includes the contents of each
+of C<@Scalars>, C<@Arrays>, C<@Hashes>, C<@Functions> and C<@Filehandles>.
+
 Similarly, C<@Barewords> adds a few non-function keywords and
 operators to the C<@Functions> array.
 
 All additions and modifications are welcome.
 
+The perl parser uses a static list of keywords from
+F<regen/keywords.pl> which constitutes the strict list of keywords
+@Functions and @Barewords, though some @Functions are not functions
+in the strict sense.
+Several library functions use more special symbols, handles and methods.
+
 =head1 DATA
 
 =over
@@ -439,6 +492,21 @@ handles, and functions.
 This is a list of other special keywords in perl including operators
 and all the control structures.
 
+=item C<@TieIOMethods>
+
+Those are special tie or PerlIO methods called by the perl core,
+namely for tieing or PerlIO::via (or both of those) or threads.
+
+=item C<@UNIVERSALMethods>
+
+Methods defined by the core package UNIVERSAL.
+
+=item C<@ExporterSymbols>
+
+Variables or functions used by Exporter (some internal), which is
+almost as good as being keywords, for you mustn't use them for any
+other purpose in any package that isa Exporter, which is quite common.
+
 =back
 
 =head1 EXPORT
@@ -448,16 +516,53 @@ everything.
 
 =head1 SEE ALSO
 
-keywords.pl from the perl source, L<perlvar>, L<perlfunc>,
+F<regen/keywords.pl> from the perl source, L<perlvar>, L<perlfunc>,
 L<perldelta>.
 
-=head1 AUTHOR
+=head1 BUGS
 
-Joshua ben Jore <jjore@cpan.org>
+Please report any bugs or feature requests to C<bug-B-Keywords at
+rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=B-Keywords>. I will be
+notified, and then you'll automatically be notified of progress on
+your bug as I make changes.
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc B::Keywords
+
+You can also look for information at:
+
+=over
+
+=item * RT: CPAN's request tracker
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=B-Keywords>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/B-Keywords>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/B-Keywords>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/B-Keywords>
+
+=back
+
+=head1 ACKNOWLEDGEMENTS
+
+Michael G Schwern, Reini Urban, Florian Ragwitz and Zsbán Ambrus
+for patches and releases.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007, Joshua ben Jore. All rights reserved.
+Copyright 2009 Joshua ben Jore, All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of either:
@@ -466,3 +571,15 @@ a) the GNU General Public License as published by the Free Software
    Foundation; version 2, or
 
 b) the "Artistic License" which comes with Perl.
+
+=head1 SOURCE AVAILABILITY
+
+This source is in Github: L<git://github.com/rurban/b-keywords.git>
+
+=head1 AUTHOR
+
+Joshua ben Jore <jjore@cpan.org>
+
+=head1 MAINTAINER
+
+Reini Urban <rurban@cpan.org>
